@@ -6,8 +6,8 @@
 #' 
 #' @param file character string
 #' @param date a \code{POSIXct} object to use to set the \code{"when.measured"}
-#'   attribute. If \code{NULL}, the default, the date is extracted from the
-#'   file header.
+#'   attribute. If \code{NULL}, the default, the date is set to the file
+#'   modification date.
 #' @param geocode A data frame with columns \code{lon} and \code{lat} used to
 #'   set attribute \code{"where.measured"}.
 #' @param label character string, but if \code{NULL} the value of \code{file} is
@@ -19,16 +19,23 @@
 #'   like the default time zone, encoding, decimal mark, big mark, and day/month
 #'   names.
 #' @param npixels integer Number of pixels in spectral data.
+#' @param spectrometer.sn character The serial number of the spectrometer needs
+#'   to be supplied by the user as it is not included in the file header.
 #'   
 #' @return A raw_spct object.
+#' 
 #' @export
 #' @references \url{https://www.r4photobiology.info} \url{https://oceanoptics.com/} \url{https://www.raspberrypi.org/}
 #' 
 #' @note The header in these files has very little information, so the user
 #' needs to supply the number of pixels in the array as well as the date-time.
-#' The file contains a date in milliseconds but as the Raspberry Pi board
+#' The file contains a time in milliseconds but as the Raspberry Pi board
 #' contains no real-time clock, it seems to default to number of milliseconds
-#' since the Pi was switched on.
+#' since the Pi was switched on. If no argument is passed to date this
+#' attribute is set to the file modification date obtained with file.mtime().
+#' This date-time gives an upper limit to the real time of measurement as in
+#' some operating systems it is reset when the file is copied or even without
+#' any good apparent reason.
 #' 
 read_oo_pidata <- function(file,
                            date = NULL,
@@ -36,7 +43,8 @@ read_oo_pidata <- function(file,
                            label = NULL,
                            tz = NULL,
                            locale = readr::default_locale(),
-                           npixels = 2048) {
+                           npixels = 2048,
+                           spectrometer.sn = "FLMS00673") {
   if (is.null(tz)) {
     tz <- locale$tz
   }
@@ -48,18 +56,65 @@ read_oo_pidata <- function(file,
     label <- paste(label.file, label, sep = "\n")
   }
   
+  first.line <- scan(file = file, nlines = 1, 
+                     skip = 0, what = "character", sep = "\n")
+  
+  skip.n <- ifelse(grepl("sequence", first.line), 1L, 0L)
+  
   file_header <- scan(file = file, nlines = 4, 
-                      skip = 0, what = "character", sep = "\n")
+                      skip = skip.n, what = "character", sep = "\n")
   
   if (is.null(date)) {
-    date <- sub("Saved at time: ", "", file_header[1], fixed = TRUE)
-    # needs further decoding if possible
+     # we use file modification time lacking anything better
+     date <- file.mtime(file)
   }
   
+  integ.time <- as.numeric(sub("Integration time: ", "", file_header[2L]))
+  
+  num.scans <- as.integer(sub("Scans to average: ", "", file_header[3L])) 
+  num.scans <- ifelse(num.scans < 1L, 1L, num.scans)
+  
+  boxcar.width <- as.integer(sub("Boxcar smoothing: ", "", file_header[4L]))
+  boxcar.width <- ifelse(boxcar.width < 1L, 1L, boxcar.width)
+  
+  inst.descriptor <-
+    list(
+      time = date,
+      w = NULL,
+      sr.index = NA_integer_,
+      ch.index = NA_integer_,
+      spectrometer.name = "OO with Raspberry Pi",
+      spectrometer.sn = spectrometer.sn,
+      bench.grating = NA_character_,
+      bench.filter = NA_character_,
+      bench.slit = NA_character_,
+      min.integ.time = NA_integer_,
+      max.integ.time = NA_integer_,
+      max.counts = NA_integer_,
+      wavelengths = NA_real_,
+      bad.pixs = numeric(),
+      inst.calib = list()
+    )
+  
+  inst.settings <- 
+    list(
+      time = date,
+      w = NULL,
+      sr.index = NA_integer_,
+      ch.index = NA_integer_,
+      correct.elec.dark =  NA_integer_,
+      correct.non.lin = NA_integer_,
+      correct.stray.light = NA_integer_,
+      boxcar.width = boxcar.width,
+      integ.time = integ.time,
+      num.scans = num.scans,
+      tot.time = integ.time * num.scans
+    )
+  
   z <- readr::read_tsv(
     file = file,
     col_names = c("w.length", "counts"),
-    skip = 5,
+    skip = 5 + skip.n,
     n_max = npixels,
     col_types = readr::cols(),
     locale = locale
@@ -73,6 +128,8 @@ read_oo_pidata <- function(file,
           paste(file_header, collapse = "\n"), 
           sep = "\n")
 
+  photobiology::setInstrDesc(z, inst.descriptor)
+  photobiology::setInstrSettings(z, inst.settings)
   photobiology::setWhenMeasured(z, date)
   photobiology::setWhereMeasured(z, geocode)
   photobiology::setWhatMeasured(z, label)
